# chess-hic

[![PyPI version](https://badge.fury.io/py/chess-hic.svg)](https://badge.fury.io/py/chess-hic)
[![Documentation Status](https://readthedocs.org/projects/chess-hic/badge/?version=latest)](https://chess-hic.readthedocs.io/en/latest/?badge=latest)

CHESS is a tool for the comparison and automatic feature extraction for chromatin contact data,
developed in the [Vaquerizas Lab](https://www.vaquerizaslab.org/).

If you use CHESS in your research, please cite the [CHESS paper](https://www.nature.com/articles/s41588-020-00712-y).

Please check out the [online documentation](https://chess-hic.readthedocs.io/en/latest/index.html)
for detailed installation and usage instructions.